==> FHLBBS-5.3.tgz: php/blist.php <==
<?php
 require("config.php");
 require("wbbs.php");
   require("auth.php");
   /******** osession ܼ  *******/
   session_register("userid","cuser","currboard","cbrd","brd_pt");
    /***** QװϥΪ ******/
   if (strlen($_REQUEST["CLASS"])>0) 
	{
		$classtr=$_REQUEST["CLASS"];
   		$listmode=1; /***pGclassѼƨSX{ANOCXҦQװ*/
		// $listmode=0 QװϦC  =1 QװϦC
	}
   else 
	{
		$listmode=0;
		$classtr="";
	}
   /**** MΪ ***/
   if (strlen($_REQUEST["QUERY"])>0) 
	{
		$searchtext=$_REQUEST["QUERY"];
   		$searchmod=1; /***pG QueryѼƨSCXӡANOM*/
		// $searchmod=1 Search mode =0 normal mode
	}
   else 
	{
		$searchmode=0;
		$searchtext="";
	}
    /******** Bz querystring  *******/
   if (strstr($QUERY_STRING,"mybbs")) 
     { //]w My BBS modeAǳƸ
	$mybbsmode=1;
        $bdir=sethomepath($cuser->userid);
	 $bfile=$bdir."/".$MYFILE;
 	if (is_file($bfile)) $MYARRAY=file($bfile);
 	else $MYARRAY=array();
 	for ($i=0;$i<count($MYARRAY);$i++) $MYARRAY[$i]=trim($MYARRAY[$i]);
     }
   else	$mybbsmode=0;
   if (strstr($QUERY_STRING,"top")) $querymode=1;
   else if (strstr($QUERY_STRING,"pgup")) $querymode=2;
   else if (strstr($QUERY_STRING,"pgdn")) $querymode=3;
   else if (strstr($QUERY_STRING,"bottom")) $querymode=4;
   else if ($listmode==0) 
        {
          if (strlen($QUERY_STRING)>0) //blist.php?12
              $curr_bcnt = (int) $QUERY_STRING;
          elseif ($brd_pt>=0) $curr_bcnt=$brd_pt; //pGsessionܼƴN
	  else $curr_bcnt=1;
        }
   else $curr_bcnt=1;

   // old strcpy(board_list,BBSHOME);


   /*** XݭnCX ***/
   $numposts=0;
      //resolve_boards();
   /****oQװϪ *****/
   $shm_id=shmop_open($BRDSHM_KEY,"a",0,0);
   $shm_size = shmop_size($shm_id);
   $shm_size = $shm_size - 4 - 4;
   $rnum = shmop_read($shm_id, $shm_size, 4);;
   $data=unpack("I1number",$rnum);
   $totposts=$data["number"]; //oQװ`
   $numboards=$totposts;
   $RECLENGTH=128;
   for($j = 0;$j < $numboards;$j++) //@ӰQװϤ@ӰQװϳBz
   {
   	$wbrd=new brdrec; //wqu@ΪQװϪŶ
	/****ŪøѶ}Qװϸ ****/
   	$ptr=shmop_read($shm_id, $j*$RECLENGTH, $RECLENGTH);
    	$wbrd->unpack($ptr);
         if (Ben_Perm($wbrd)) // 禳LiQװϪv 
         { 
            if ($searchmode==1) 
            {
                if ((strstr($wbrd->brdname,searchtext)===false)&&
                    (strstr($wbrd->title,searchtext)===false)&&
                    (strstr($wbrd->BM,searchtext)===false)) //䤣
                    continue;
            }
            if ($mybbsmode==1) // mybbs
            {
		if (in_array($wbrd->brdname,$MYARRAY))
                         $boardbuf[$numposts++]=$wbrd; //N[J}C
            }
	    else
            {
	       $liststr=substr($wbrd->title,1,4);
               if ($listmode==1) // pGOQװϡANˬdr 
    	       {
 	       	  if (strstr($classtr,$liststr)||strncmp($classtr,"*",1)==0) 
                         $boardbuf[$numposts++]=$wbrd; //N[J}C
  	       }
	       else //CXҦ
	         if ((strstr("",$liststr)===false)&&
		    (strstr("",$liststr)===false))//HRCXΪ
                         $boardbuf[$numposts++]=$wbrd; //N[J}C
            } // else my bbs
         } 
      } // for 
  
   /* WUkBz ***/
   if ($querymode==2)
      $start=($brd_pt-$SHOWNUM > 0) ? ($brd_pt-$SHOWNUM) : 1;
   else if ($querymode==3)
      $start=($brd_pt+$SHOWNUM < $numposts-$SHOWNUM) ? 
      ($brd_pt+$SHOWNUM):$numposts-$SHOWNUM+1;
   else if ($querymode==1) $start=1;
   else if ($querymode==4) $start= $numposts-$SHOWNUM+1;
   else if ($curr_bcnt <= 0) $start=1; //Y}lnF
   else if ($curr_bcnt > $numposts) 
	$start = ($numposts - $SHOWNUM > 0) ? ($numposts - $SHOWNUM+1) : 1;
   else
      $start = $curr_bcnt;
   /*** oؽsJsession ***/
   $brd_pt=$start;
   /********* } ***/
   if ($listmode==1) $buf2=$DEFDIR[$doorid].$CLASSLISTPRE;
   else $buf2=$DEFDIR[$doorid].$BLISTPRE;
   if( ($fp = fopen($buf2,"r")) === false )
     	die ("$buf2 ɮ׶}ҿ~<br>");
    /*LXҪɮ **/
    while (!feof($fp))
    {
    	$genbuf=fgets($fp,1000);
        if ($mybbsmode==1)
	{
	   $genbuf=str_replace("[JMy BBS","My BBSR",$genbuf);
	   $genbuf=str_replace("value=\"add\"","value=\"del\"",$genbuf);
	}
    	$pt1=$genbuf;
    	while (!(($pt2=strpos($pt1,"<!--$"))===false))
    	{
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
            		die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else
            {
               /***** LXQװϦC ********/
           	echo "<table>\n";
           	echo "<tr><td></td><td>s</td><td>Ū</td><td>g</td>";
           	echo  "<td>W</td><td>D</td><td>D</td></tr>";
           	$buf ="$HOME/.BOARDS";
           	$cntx=0;
           	$end1 = $numposts;
		//$boardbuf[$numposts++]=$wbrd
 		$brc=new ubrcrec;
                $showcnt=0;
           
            	for($j = $start-1; $j < $end1 ;$j++)
            	{
		   $showcnt++;
              	/** HU}lLXQװϸ ***/
 	           $buf1="{$BBSHOME}/boards/{$boardbuf[$j]->brdname}/.DIR";
	      	   if (($bnumposts=filesize($buf1))===false) $bnumposts=0;
	           else $bnumposts=$bnumposts/$dirlength;
                   $cntx++;
	           $fd1= fopen($buf1, "r" );
  	           fseek($fd1, ($bnumposts - 1) * $dirlength, SEEK_SET);
		   $fname=fread($fd1,$FNLEN);
		   //$fname=strtok(trim($fname),chr(0));
		   $fname=trim($fname);
                   if (strlen($fname)==0) die("S峹ɦWI");
   		   $ptj=$brc->brc_initial($boardbuf[$j]->brdname);
		   if ($ptj==0) $unread = 1;
		   else $unread = $brc->brc_unread($fname);
		   fclose($fd1);
		   
                   $out=sprintf("<tr><td><input name=\"m%d\" type=checkbox value=\"%s\"></td><td>%3d</td><td>%s</td><td>%d</td>"
                   ,$showcnt,$boardbuf[$j]->brdname,$start+$cntx-1,$unread?"" : "",$bnumposts);
		   echo $out;
                   $out=sprintf("<td><a href=\"boards.php?%s\">%s</a></td><td><a href=\"boards.php?%s\">%s</a></td>\n",
                   $boardbuf[$j]->brdname,$boardbuf[$j]->brdname,
                   $boardbuf[$j]->brdname,substr($boardbuf[$j]->title,5));
		   echo $out;
	           if (strlen($boardbuf[$j]->BM)>0)
		            echo "<td>{$boardbuf[$j]->BM}</td></tr>";
	           else
		          echo "<td>xD</td></tr>\n";
                   if (($cntx==SHOWNUM)&&($listmode==0)) //CX~
                       $j=$end1;
                   $isprint=1;
          	} // for j
         echo "</table>\n";
         if ($isprint==0)
             echo "<h2>SQװϲŦXnDI<br></h2>\n";
         } //Dn\ else
     } //while <!--$
     echo $pt1;
   } // while get oneline
      fclose($fp);
     shmop_close($shm_id);
?>

==> FHLBBS-5.4.tgz: php/blist.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 function cmp ($a, $b) {
	return(strcasecmp($a->brdname, $b->brdname));
 }
   /******** osession ܼ  *******/
   session_register("userid","cuser","currboard","cbrd","brd_pt");
    /***** QװϥΪ ******/
   if (strlen($_REQUEST["CLASS"])>0) 
	{
		$classtr=$_REQUEST["CLASS"];
   		$listmode=1; /***pGclassѼƨSX{ANOCXҦQװ*/
		// $listmode=0 QװϦC  =1 QװϦC
	}
   else 
	{
		$listmode=0;
		$classtr="";
	}
   /**** MΪ ***/
   if (strlen($_REQUEST["QUERY"])>0) 
	{
		$searchtext=$_REQUEST["QUERY"];
   		$searchmod=1; /***pG QueryѼƨSCXӡANOM*/
		// $searchmod=1 Search mode =0 normal mode
	}
   else 
	{
		$searchmode=0;
		$searchtext="";
	}
    /******** Bz querystring  *******/
   if (strstr($QUERY_STRING,"mybbs")) 
     { //]w My BBS modeAǳƸ
	$mybbsmode=1;
        $bdir=sethomepath($cuser->userid);
	 $bfile=$bdir."/".$MYFILE;
 	if (is_file($bfile)) $MYARRAY=file($bfile);
 	else $MYARRAY=array();
 	for ($i=0;$i<count($MYARRAY);$i++) $MYARRAY[$i]=trim($MYARRAY[$i]);
     }
   else	$mybbsmode=0;
   if (strstr($QUERY_STRING,"top")) $querymode=1;
   else if (strstr($QUERY_STRING,"pgup")) $querymode=2;
   else if (strstr($QUERY_STRING,"pgdn")) $querymode=3;
   else if (strstr($QUERY_STRING,"bottom")) $querymode=4;
   else if ($listmode==0) 
        {
          if (strlen($QUERY_STRING)>0) //blist.php?12
              $curr_bcnt = (int) $QUERY_STRING;
          elseif ($brd_pt>=0) $curr_bcnt=$brd_pt; //pGsessionܼƴN
	  else $curr_bcnt=1;
        }
   else $curr_bcnt=1;

   // old strcpy(board_list,BBSHOME);


   /*** XݭnCX ***/
   $numposts=0;
      //resolve_boards();
   /****oQװϪ *****/
   $shm_id=shmop_open($BRDSHM_KEY,"a",0,0);
   $shm_size = shmop_size($shm_id);
   $shm_size = $shm_size - 4 - 4;
   $rnum = shmop_read($shm_id, $shm_size, 4);;
   $data=unpack("I1number",$rnum);
   $totposts=$data["number"]; //oQװ`
   $numboards=$totposts;
   $RECLENGTH=128;
   for($j = 0;$j < $numboards;$j++) //@ӰQװϤ@ӰQװϳBz
   {
   	$wbrd=new brdrec; //wqu@ΪQװϪŶ
	/****ŪøѶ}Qװϸ ****/
   	$ptr=shmop_read($shm_id, $j*$RECLENGTH, $RECLENGTH);
    	$wbrd->unpack($ptr);
         if (Ben_Perm($wbrd)) // 禳LiQװϪv 
         { 
            if ($searchmode==1) 
            {
                if ((strstr($wbrd->brdname,searchtext)===false)&&
                    (strstr($wbrd->title,searchtext)===false)&&
                    (strstr($wbrd->BM,searchtext)===false)) //䤣
                    continue;
            }
            if ($mybbsmode==1) // mybbs
            {
		if (in_array($wbrd->brdname,$MYARRAY))
                         $boardbuf[$numposts++]=$wbrd; //N[J}C
            }
	    else
            {
	       $liststr=substr($wbrd->title,1,4);
               if ($listmode==1) // pGOQװϡANˬdr 
    	       {
 	       	  if (strstr($classtr,$liststr)||strncmp($classtr,"*",1)==0) 
                         $boardbuf[$numposts++]=$wbrd; //N[J}C
  	       }
	       else //CXҦ
	         if ((strstr("",$liststr)===false)&&
		    (strstr("",$liststr)===false))//HRCXΪ
                         $boardbuf[$numposts++]=$wbrd; //N[J}C
            } // else my bbs
         } 
      } // for 
      usort($boardbuf,"cmp");
  
   /* WUkBz ***/
   if ($querymode==2)
      $start=($brd_pt-$SHOWNUM > 0) ? ($brd_pt-$SHOWNUM) : 1;
   else if ($querymode==3)
      $start=($brd_pt+$SHOWNUM < $numposts-$SHOWNUM) ? 
      ($brd_pt+$SHOWNUM):$numposts-$SHOWNUM+1;
   else if ($querymode==1) $start=1;
   else if ($querymode==4) $start= $numposts-$SHOWNUM+1;
   else if ($curr_bcnt <= 0) $start=1; //Y}lnF
   else if ($curr_bcnt > $numposts) 
	$start = ($numposts - $SHOWNUM > 0) ? ($numposts - $SHOWNUM+1) : 1;
   else
      $start = $curr_bcnt;
   /*** oؽsJsession ***/
   $brd_pt=$start;
   /********* } ***/
   if ($listmode==1) $buf2=$DEFDIR[$doorid].$CLASSLISTPRE;
   else $buf2=$DEFDIR[$doorid].$BLISTPRE;
   if( ($fp = fopen($buf2,"r")) === false )
     	die ("$buf2 ɮ׶}ҿ~<br>");
    /*LXҪɮ **/
    while (!feof($fp))
    {
    	$genbuf=fgets($fp,1000);
        if ($mybbsmode==1)
	{
	   $genbuf=str_replace("[JMy BBS","My BBSR",$genbuf);
	   $genbuf=str_replace("value=\"add\"","value=\"del\"",$genbuf);
	}
    	$pt1=$genbuf;
    	while (!(($pt2=strpos($pt1,"<!--$"))===false))
    	{
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
            		die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else
            {
               /***** LXQװϦC ********/
           	echo "<table>\n";
           	echo "<tr><td></td><td>s</td><td>Ū</td><td>g</td>";
           	echo  "<td>W</td><td>D</td><td>D</td></tr>";
           	$buf ="$HOME/.BOARDS";
           	$cntx=0;
           	$end1 = $numposts;
		//$boardbuf[$numposts++]=$wbrd
 		$brc=new ubrcrec;
                $showcnt=0;
           
            	for($j = $start-1; $j < $end1 ;$j++)
            	{
		   $showcnt++;
              	/** HU}lLXQװϸ ***/
 	           $buf1="{$BBSHOME}/boards/{$boardbuf[$j]->brdname}/.DIR";
	      	   if (($bnumposts=filesize($buf1))===false) $bnumposts=0;
	           else $bnumposts=$bnumposts/$dirlength;
                   $cntx++;
	           $fd1= fopen($buf1, "r" );
  	           fseek($fd1, ($bnumposts - 1) * $dirlength, SEEK_SET);
		   $fname=fread($fd1,$FNLEN);
		   //$fname=strtok(trim($fname),chr(0));
		   $fname=trim($fname);
                   if (strlen($fname)==0) die("S峹ɦWI");
   		   $ptj=$brc->brc_initial($boardbuf[$j]->brdname);
		   if ($ptj==0) $unread = 1;
		   else $unread = $brc->brc_unread($fname);
		   fclose($fd1);
		   $cj=$j%2; 
                   $out=sprintf("<tr><td{$tcolor[$cj]}><input name=\"m%d\" type=checkbox value=\"%s\"></td><td{$tcolor[$cj]}>%3d</td><td{$tcolor[$cj]}>%s</td><td{$tcolor[$cj]}>%d</td>"
                   ,$showcnt,$boardbuf[$j]->brdname,$start+$cntx-1,$unread?"" : "",$bnumposts);
		   echo $out;
                   $out=sprintf("<td{$tcolor[$cj]}><a href=\"boards.php?%s\">%s</a></td><td{$tcolor[$cj]}><a href=\"boards.php?%s\">%s</a></td>\n",
                   $boardbuf[$j]->brdname,$boardbuf[$j]->brdname,
                   $boardbuf[$j]->brdname,substr($boardbuf[$j]->title,5));
		   echo $out;
	           if (strlen($boardbuf[$j]->BM)>0)
		            echo "<td{$tcolor[$cj]}>{$boardbuf[$j]->BM}</td></tr>";
	           else
		          echo "<td{$tcolor[$cj]}>xD</td></tr>\n";
                   if (($cntx==SHOWNUM)&&($listmode==0)) //CX~
                       $j=$end1;
                   $isprint=1;
          	} // for j
         echo "</table>\n";
         if ($isprint==0)
             echo "<h2>SQװϲŦXnDI<br></h2>\n";
         } //Dn\ else
     } //while <!--$
     echo $pt1;
   } // while get oneline
      fclose($fp);
     shmop_close($shm_id);
?>
